#! /bin/python
#Benjamin Kibalo, March 2013
#temperature monitoring program for Raspberry Pi
#make sure to put all of the files into the same directory on the Raspberry Pi

from get_temp import *
from led import *
from emailnotify import *
from takepic import *
from gdoc import *
import time

#setup notification parameters
max_temp = 29       #maxmimum allowable temp in C
bad_readings = 3   #number of bad readings before notification
measure_delay = 1   #time delay between readings in seconds
email_addr = "notifyemail@gmail.com"  #put in your email address here that you want to notify 
email_subject = "RPi ALERT Notification!"  #subject of the email to send using emailnotify.py
pic_save = "notify_pic.jpg"

#initialize your variables for the main program
temp_reading = 0
oos = 0 #this initializes the out of spec (OOS) variable, which monitors the number of cycles over temp prior to emailing 
row = 0 #this is the row were the google spreadsheet will start, if you restart the program, it will start at this row again
#potentially overwriting your old data, keep this in mind

init_temp()  #access init_temp and send the commands to export the temperature sensor information

while True:
    temp_reading = temp_measure()  #access the temp_measure() function and set the value to temp_reading
    
    if temp_reading > max_temp:  #this conditional statement looks to see if the temp is greater than max temp
        set_LED('red', 'on')  #call set_LED and turn on red led (send command even if the red led is on already)
        set_LED('green', 'off') #call set_LED and turn off green led (send command even if the green led is off already)
        oos = oos + 1  #inrement oos variable

    else:                      #condition that the temperature is less than the threshold max temp (everything is OK)
        set_LED('red', 'off')  #call set_LED and set red LED to off (even if red led is off already)
        set_LED('green', 'on') #call set_LED and set green LED to on (even if green led is on already)
        oos = 0 #reset the oos variable to 0

    if oos > bad_readings:  #check the oos variable to see if it has exceed out preset threshold in bad_readings
        oos = 0  #reset the oos variable so we don't get 100 emails about the same issue
        take_pic(pic_save) #take a picture of the situation
        emailer(email_addr, email_subject + " " + str(temp_reading) + 
          " degC", pic_save) #send an email with the details, including the actual temperature and a picture attachment
    
    gdoc_update(temp_reading, row)  #update our google docs spreadsheet with the latest temperature info
    row = row + 1  #increment the row variable for the next google spreadsheet data entry
    time.sleep(measure_delay)  #wait for the predetermined time delay before doing another reading

